DerivedRankBasedMetric
======================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: DerivedRankBasedMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DerivedRankBasedMetric.base_cls
      ~DerivedRankBasedMetric.binarize
      ~DerivedRankBasedMetric.closed_expectation
      ~DerivedRankBasedMetric.closed_variance
      ~DerivedRankBasedMetric.key
      ~DerivedRankBasedMetric.needs_candidates
      ~DerivedRankBasedMetric.supported_rank_types
      ~DerivedRankBasedMetric.supports_weights
      ~DerivedRankBasedMetric.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~DerivedRankBasedMetric.__call__
      ~DerivedRankBasedMetric.adjust
      ~DerivedRankBasedMetric.expected_value
      ~DerivedRankBasedMetric.extra_repr
      ~DerivedRankBasedMetric.get_coefficients
      ~DerivedRankBasedMetric.get_description
      ~DerivedRankBasedMetric.get_link
      ~DerivedRankBasedMetric.get_range
      ~DerivedRankBasedMetric.get_sampled_values
      ~DerivedRankBasedMetric.iter_extra_repr
      ~DerivedRankBasedMetric.numeric_expected_value
      ~DerivedRankBasedMetric.numeric_expected_value_with_ci
      ~DerivedRankBasedMetric.numeric_variance
      ~DerivedRankBasedMetric.numeric_variance_with_ci
      ~DerivedRankBasedMetric.std
      ~DerivedRankBasedMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: base_cls
   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: key
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
